@@ -40,7 +40,7 @@ setMethodS3("report", "AbstractCBS", function(fit, sampleName=getSampleName(fit)
   require("R.rsp", quietly=TRUE) || throw("Package not loaded: R.rsp");
   ver <- packageVersion("R.rsp");
   if (ver < "0.9.1") {
-    throw("The PSCBS report generator requires R.rsp v0.9.1 or greater: ", ver);
+    throw("The PSCBS report generator requires R.rsp v0.9.1 or newer: ", ver);
   }
 
 
